pub struct FSContainerStatus { /* private fields */ }FSContainer only.Expand description
A type that represents a container’s status.
This type contains two properties:
- The
statevalue that indicates the state of the container, such asFSContainerState/readyorFSContainerState/blocked. - The
statusis an error (optional in Swift, nullable in Objective-C) that provides further information about the state, such as why the container is blocked.
Examples of statuses that require intervention include errors that indicate the container isn’t ready (POSIX EAGAIN or ENOTCONN), the container needs authentication (ENEEDAUTH), or that authentication failed (EAUTH).
The status can also be an informative error, such as the FSKit error FSErrorStatusOperationInProgress, possibly with the variant information of FSKitErrorVariantCheckStatus or FSKitErrorVariantFormatStatus.
See also Apple’s documentation
Implementations
Sourceimpl FSContainerStatus
impl FSContainerStatus
Sourcepub unsafe fn state(&self) -> FSContainerState
pub unsafe fn state(&self) -> FSContainerState
A value that represents the container state, such as ready, active, or blocked.
Sourcepub unsafe fn status(&self) -> Option<Retained<NSError>>
pub unsafe fn status(&self) -> Option<Retained<NSError>>
An optional error that provides further information about the state.
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourcepub unsafe fn active() -> Retained<FSContainerStatus>
pub unsafe fn active() -> Retained<FSContainerStatus>
A status that represents an active container with no error.
This value is a FSContainerStatus with a state that is active, and has a status that is nil.
Sourcepub unsafe fn activeWithStatus(error_status: &NSError) -> Retained<Self>
pub unsafe fn activeWithStatus(error_status: &NSError) -> Retained<Self>
Returns a active container status instance with the provided error status.
- Parameter errorStatus: The error status, if any, for the new instance.
Sourcepub unsafe fn blockedWithStatus(error_status: &NSError) -> Retained<Self>
pub unsafe fn blockedWithStatus(error_status: &NSError) -> Retained<Self>
Returns a blocked container status instance with the provided error status.
- Parameter errorStatus: The error status, if any, for the new instance.
Sourcepub unsafe fn notReadyWithStatus(error_status: &NSError) -> Retained<Self>
pub unsafe fn notReadyWithStatus(error_status: &NSError) -> Retained<Self>
Returns a not-ready container status instance with the provided error status.
- Parameter errorStatus: The error status, if any, for the new instance.
Sourcepub unsafe fn ready() -> Retained<FSContainerStatus>
pub unsafe fn ready() -> Retained<FSContainerStatus>
A status that represents a ready container with no error.
This value is a FSContainerStatus with a state that is ready, and a status that is nil.
Sourcepub unsafe fn readyWithStatus(error_status: &NSError) -> Retained<Self>
pub unsafe fn readyWithStatus(error_status: &NSError) -> Retained<Self>
Returns a ready container status instance with the provided error status.
- Parameter errorStatus: The error status, if any, for the new instance.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for FSContainerStatus
impl AsRef<AnyObject> for FSContainerStatus
Sourceimpl AsRef<FSContainerStatus> for FSContainerStatus
impl AsRef<FSContainerStatus> for FSContainerStatus
Sourceimpl AsRef<NSObject> for FSContainerStatus
impl AsRef<NSObject> for FSContainerStatus
Sourceimpl Borrow<AnyObject> for FSContainerStatus
impl Borrow<AnyObject> for FSContainerStatus
Sourceimpl Borrow<NSObject> for FSContainerStatus
impl Borrow<NSObject> for FSContainerStatus
Sourceimpl ClassType for FSContainerStatus
impl ClassType for FSContainerStatus
Sourceconst NAME: &'static str = "FSContainerStatus"
const NAME: &'static str = "FSContainerStatus"
Sourcetype ThreadKind = <<FSContainerStatus as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<FSContainerStatus as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl CopyingHelper for FSContainerStatus
impl CopyingHelper for FSContainerStatus
Sourcetype Result = FSContainerStatus
type Result = FSContainerStatus
Self if the type has no
immutable counterpart. Read moreSourceimpl Debug for FSContainerStatus
impl Debug for FSContainerStatus
Sourceimpl Deref for FSContainerStatus
impl Deref for FSContainerStatus
Sourceimpl Hash for FSContainerStatus
impl Hash for FSContainerStatus
Sourceimpl Message for FSContainerStatus
impl Message for FSContainerStatus
Sourceimpl NSCopying for FSContainerStatus
impl NSCopying for FSContainerStatus
Sourceimpl NSObjectProtocol for FSContainerStatus
impl NSObjectProtocol for FSContainerStatus
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref