pub struct FSDirectoryEntryPacker { /* private fields */ }FSVolume only.Expand description
An object used to provide items during a directory enumeration.
You use this type in your implementation of FSVolume/Operations/enumerateDirectory(_:startingAt:verifier:attributes:packer:replyHandler:).
Packing allows your implementation to provide information FSKit needs, including each item’s name, type, and identifier (such as an inode number).
Some directory enumerations require other attributes, as indicated by the FSItemGetAttributesRequest sent to the enumerate method.
See also Apple’s documentation
Implementations
Sourceimpl FSDirectoryEntryPacker
impl FSDirectoryEntryPacker
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourcepub unsafe fn packEntryWithName_itemType_itemID_nextCookie_attributes(
&self,
name: &FSFileName,
item_type: FSItemType,
item_id: FSItemID,
next_cookie: FSDirectoryCookie,
attributes: Option<&FSItemAttributes>,
) -> bool
Available on crate features FSFileName and FSItem only.
pub unsafe fn packEntryWithName_itemType_itemID_nextCookie_attributes( &self, name: &FSFileName, item_type: FSItemType, item_id: FSItemID, next_cookie: FSDirectoryCookie, attributes: Option<&FSItemAttributes>, ) -> bool
FSFileName and FSItem only.Provides a directory entry during enumeration.
You call this method in your implementation of FSVolume/Operations/enumerateDirectory(_:startingAt:verifier:attributes:packer:replyHandler:), for each directory entry you want to provide to the enumeration.
- Parameters:
- name: The item’s name.
- itemType: The type of the item.
- itemID: The item’s identifier.
- nextCookie: A value to indicate the next entry in the directory to enumerate. FSKit passes this value as the
cookieparameter on the next call toFSVolume/Operations/enumerateDirectory(_:startingAt:verifier:attributes:packer:replyHandler:). Use whatever value is appropriate for your implementation; the value is opaque to FSKit. - attributes: The item’s attributes. Pass
nilif the enumeration call didn’t request attributes. - Returns:
true(Swift) orYES(Objective-C) if packing was successful and enumeration can continue with the next directory entry. If the value isfalse(Swift) orNO(Objective-C), stop enumerating. This result can happen when the entry is too big for the remaining space in the buffer.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for FSDirectoryEntryPacker
impl AsRef<AnyObject> for FSDirectoryEntryPacker
Sourceimpl AsRef<NSObject> for FSDirectoryEntryPacker
impl AsRef<NSObject> for FSDirectoryEntryPacker
Sourceimpl Borrow<AnyObject> for FSDirectoryEntryPacker
impl Borrow<AnyObject> for FSDirectoryEntryPacker
Sourceimpl Borrow<NSObject> for FSDirectoryEntryPacker
impl Borrow<NSObject> for FSDirectoryEntryPacker
Sourceimpl ClassType for FSDirectoryEntryPacker
impl ClassType for FSDirectoryEntryPacker
Sourceconst NAME: &'static str = "FSDirectoryEntryPacker"
const NAME: &'static str = "FSDirectoryEntryPacker"
Sourcetype ThreadKind = <<FSDirectoryEntryPacker as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<FSDirectoryEntryPacker as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for FSDirectoryEntryPacker
impl Debug for FSDirectoryEntryPacker
Sourceimpl Deref for FSDirectoryEntryPacker
impl Deref for FSDirectoryEntryPacker
Sourceimpl Hash for FSDirectoryEntryPacker
impl Hash for FSDirectoryEntryPacker
Sourceimpl Message for FSDirectoryEntryPacker
impl Message for FSDirectoryEntryPacker
Sourceimpl NSObjectProtocol for FSDirectoryEntryPacker
impl NSObjectProtocol for FSDirectoryEntryPacker
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref