FSEntityIdentifier

Struct FSEntityIdentifier 

pub struct FSEntityIdentifier { /* private fields */ }
Available on crate feature FSEntityIdentifier only.
A base type that identifies containers and volumes.

An FSEntityIdentifier is a UUID to identify a container or volume, optionally with eight bytes of qualifying (differentiating) data. You use the qualifiers in cases in which a file server can receive multiple connections from the same client, which differ by user credentials. In this case, the identifier for each client is the server’s base UUID, and a unique qualifier that differs by client.

Important: Don’t subclass this class.

See also Apple’s documentation

Implementations

Source

impl FSEntityIdentifier

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

Creates an entity identifier with a random UUID.

pub unsafe fn initWithUUID( this: Allocated<Self>, uuid: &NSUUID, ) -> Retained<Self>

Creates an entity identifier with the given UUID.

  • Parameter uuid: The UUID to use for this identifier.
pub unsafe fn initWithUUID_qualifier( this: Allocated<Self>, uuid: &NSUUID, qualifier: u64, ) -> Retained<Self>

Creates an entity identifier with the given UUID and qualifier data as a 64-bit unsigned integer.

  • Parameters:
  • uuid: The UUID to use for this identifier.
  • qualifier: The data to distinguish entities that otherwise share the same UUID.
pub unsafe fn initWithUUID_data( this: Allocated<Self>, uuid: &NSUUID, qualifier_data: &NSData, ) -> Retained<Self>

Creates an entity identifier with the given UUID and qualifier data.

  • Parameters:
  • uuid: The UUID to use for this identifier.
  • qualifierData: The data to distinguish entities that otherwise share the same UUID.
pub unsafe fn uuid(&self) -> Retained<NSUUID>

A UUID to uniquely identify this entity.

pub unsafe fn setUuid(&self, uuid: &NSUUID)

Setter for uuid.

This is copied when set.

pub unsafe fn qualifier(&self) -> Option<Retained<NSData>>

An optional piece of data to distinguish entities that otherwise share the same UUID.

pub unsafe fn setQualifier(&self, qualifier: Option<&NSData>)

Setter for qualifier.

This is copied when set.

Source

impl FSEntityIdentifier

Methods declared on superclass NSObject.

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}