FSErrorCode

Struct FSErrorCode 

#[repr(transparent)]
pub struct FSErrorCode(pub NSInteger);
Available on crate feature FSKitError only.
A code that indicates a specific FSKit error.

See also Apple’s documentation

Tuple Fields

0: NSInteger

Implementations

Source

impl FSErrorCode

pub const ModuleLoadFailed: Self

The module failed to load.

pub const ResourceUnrecognized: Self

FSKit didn’t recognize the resource, and probing failed to find a match.

pub const ResourceDamaged: Self

The resource is damaged.

This error indicates the resource needs a repair operation, or that a repair operation failed.

Note: The status in this error applies to the resource. A failing repair operation reports a more specific error status.

pub const ResourceUnusable: Self

FSKit recognizes the resource, but the resource isn’t usable.

For example, this error occurs when a resource uses a file system’s internal feature flags. If the only modules that support the file system don’t support those feature flags, this code indicates an unusable resource. The error tells the person using the module why the resource isn’t usable.

pub const StatusOperationInProgress: Self

An operation is in progress.

pub const StatusOperationPaused: Self

An operation is paused.

pub const InvalidDirectoryCookie: Self

While enumerating a directory, the given cookie didn’t resolve to a valid directory entry.