pub struct FSExtentPacker { /* private fields */ }FSVolumeExtent only.Expand description
A type that directs the kernel to map space on disk to a specific file managed by this file system.
Extents provide the kernel the logical-to-physical mapping of a given file. An extent describes a physical offset on disk, and a length and a logical offset within the file. Rather than working with extents directly, you use this type’s methods to provide or “pack” extent information, which FSKit then passes to the kernel.
See also Apple’s documentation
Implementations
Sourceimpl FSExtentPacker
impl FSExtentPacker
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourcepub unsafe fn packExtentWithResource_type_logicalOffset_physicalOffset_length(
&self,
resource: &FSBlockDeviceResource,
type: FSExtentType,
logical_offset: off_t,
physical_offset: off_t,
length: usize,
) -> bool
Available on crate features FSResource and libc only.
pub unsafe fn packExtentWithResource_type_logicalOffset_physicalOffset_length( &self, resource: &FSBlockDeviceResource, type: FSExtentType, logical_offset: off_t, physical_offset: off_t, length: usize, ) -> bool
FSResource and libc only.Packs a single extent to send to the kernel.
- Parameters:
- resource: The resource on which to perform I/O.
- type: The type of extent, indicating whether it contains valid data.
- logicalOffset: The extent offset within the file, in bytes.
- physicalOffset: The extent offset on disk, in bytes.
- length: The extent length, in bytes.
- Returns: A Boolean value that indicates whether the packer can pack more extents.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for FSExtentPacker
impl AsRef<AnyObject> for FSExtentPacker
Sourceimpl AsRef<FSExtentPacker> for FSExtentPacker
impl AsRef<FSExtentPacker> for FSExtentPacker
Sourceimpl AsRef<NSObject> for FSExtentPacker
impl AsRef<NSObject> for FSExtentPacker
Sourceimpl Borrow<AnyObject> for FSExtentPacker
impl Borrow<AnyObject> for FSExtentPacker
Sourceimpl Borrow<NSObject> for FSExtentPacker
impl Borrow<NSObject> for FSExtentPacker
Sourceimpl ClassType for FSExtentPacker
impl ClassType for FSExtentPacker
Sourceconst NAME: &'static str = "FSExtentPacker"
const NAME: &'static str = "FSExtentPacker"
Sourcetype ThreadKind = <<FSExtentPacker as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<FSExtentPacker as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for FSExtentPacker
impl Debug for FSExtentPacker
Sourceimpl Deref for FSExtentPacker
impl Deref for FSExtentPacker
Sourceimpl Hash for FSExtentPacker
impl Hash for FSExtentPacker
Sourceimpl Message for FSExtentPacker
impl Message for FSExtentPacker
Sourceimpl NSObjectProtocol for FSExtentPacker
impl NSObjectProtocol for FSExtentPacker
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref