pub struct FSItemSetAttributesRequest { /* private fields */ }FSItem only.Expand description
A request to set attributes on an item.
Methods that take attributes use this type to receive attribute values and to indicate which attributes they support.
The various members of the parent type, FSItemAttributes, contain the values of the attributes to set.
Modify the consumedAttributes property to indicate which attributes your file system successfully used.
FSKit calls the wasAttributeConsumed(_:) method to determine whether the file system successfully used a given attribute.
Only set the attributes that your file system supports.
See also Apple’s documentation
Implementations
Sourceimpl FSItemSetAttributesRequest
impl FSItemSetAttributesRequest
Sourcepub unsafe fn consumedAttributes(&self) -> FSItemAttribute
pub unsafe fn consumedAttributes(&self) -> FSItemAttribute
The attributes successfully used by the file system.
This property is a bit field in Objective-C and an <doc ://com.apple.documentation/documentation/Swift/OptionSet> in Swift.
Sourcepub unsafe fn setConsumedAttributes(&self, consumed_attributes: FSItemAttribute)
pub unsafe fn setConsumedAttributes(&self, consumed_attributes: FSItemAttribute)
Setter for consumedAttributes.
Sourcepub unsafe fn wasAttributeConsumed(&self, attribute: FSItemAttribute) -> bool
pub unsafe fn wasAttributeConsumed(&self, attribute: FSItemAttribute) -> bool
A method that indicates whether the file system used the given attribute.
- Parameter attribute: The
FSItemAttributeto check.
Methods from Deref<Target = FSItemAttributes>
Sourcepub unsafe fn invalidateAllProperties(&self)
pub unsafe fn invalidateAllProperties(&self)
Marks all attributes inactive.
Sourcepub unsafe fn mode(&self) -> u32
pub unsafe fn mode(&self) -> u32
The mode of the item.
The mode is often used for setuid, setgid, and sticky bits.
Sourcepub unsafe fn type(&self) -> FSItemType
pub unsafe fn type(&self) -> FSItemType
The item type, such as a regular file, directory, or symbolic link.
Sourcepub unsafe fn setType(&self, type: FSItemType)
pub unsafe fn setType(&self, type: FSItemType)
Setter for type.
Sourcepub unsafe fn setLinkCount(&self, link_count: u32)
pub unsafe fn setLinkCount(&self, link_count: u32)
Setter for linkCount.
Sourcepub unsafe fn flags(&self) -> u32
pub unsafe fn flags(&self) -> u32
The item’s behavior flags.
See st_flags in stat.h for flag definitions.
Sourcepub unsafe fn setAllocSize(&self, alloc_size: u64)
pub unsafe fn setAllocSize(&self, alloc_size: u64)
Setter for allocSize.
Sourcepub unsafe fn setParentID(&self, parent_id: FSItemID)
pub unsafe fn setParentID(&self, parent_id: FSItemID)
Setter for parentID.
Sourcepub unsafe fn supportsLimitedXAttrs(&self) -> bool
pub unsafe fn supportsLimitedXAttrs(&self) -> bool
A Boolean value that indicates whether the item supports a limited set of extended attributes.
Sourcepub unsafe fn setSupportsLimitedXAttrs(&self, supports_limited_x_attrs: bool)
pub unsafe fn setSupportsLimitedXAttrs(&self, supports_limited_x_attrs: bool)
Setter for supportsLimitedXAttrs.
Sourcepub unsafe fn inhibitKernelOffloadedIO(&self) -> bool
pub unsafe fn inhibitKernelOffloadedIO(&self) -> bool
A Boolean value that indicates whether the file system overrides the per-volume settings for kernel offloaded I/O for a specific file.
This property has no meaning if the volume doesn’t conform to FSVolumeKernelOffloadedIOOperations.
Sourcepub unsafe fn setInhibitKernelOffloadedIO(
&self,
inhibit_kernel_offloaded_io: bool,
)
pub unsafe fn setInhibitKernelOffloadedIO( &self, inhibit_kernel_offloaded_io: bool, )
Setter for inhibitKernelOffloadedIO.
Sourcepub unsafe fn isValid(&self, attribute: FSItemAttribute) -> bool
pub unsafe fn isValid(&self, attribute: FSItemAttribute) -> bool
Returns a Boolean value that indicates whether the attribute is valid.
If the value returned by this method is YES (Objective-C) or true (Swift), a caller can safely use the given attribute.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for FSItemSetAttributesRequest
impl AsRef<AnyObject> for FSItemSetAttributesRequest
Sourceimpl AsRef<FSItemAttributes> for FSItemSetAttributesRequest
impl AsRef<FSItemAttributes> for FSItemSetAttributesRequest
Sourcefn as_ref(&self) -> &FSItemAttributes
fn as_ref(&self) -> &FSItemAttributes
Sourceimpl AsRef<NSObject> for FSItemSetAttributesRequest
impl AsRef<NSObject> for FSItemSetAttributesRequest
Sourceimpl Borrow<AnyObject> for FSItemSetAttributesRequest
impl Borrow<AnyObject> for FSItemSetAttributesRequest
Sourceimpl Borrow<FSItemAttributes> for FSItemSetAttributesRequest
impl Borrow<FSItemAttributes> for FSItemSetAttributesRequest
Sourcefn borrow(&self) -> &FSItemAttributes
fn borrow(&self) -> &FSItemAttributes
Sourceimpl Borrow<NSObject> for FSItemSetAttributesRequest
impl Borrow<NSObject> for FSItemSetAttributesRequest
Sourceimpl ClassType for FSItemSetAttributesRequest
impl ClassType for FSItemSetAttributesRequest
Sourceconst NAME: &'static str = "FSItemSetAttributesRequest"
const NAME: &'static str = "FSItemSetAttributesRequest"
Sourcetype Super = FSItemAttributes
type Super = FSItemAttributes
Sourcetype ThreadKind = <<FSItemSetAttributesRequest as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<FSItemSetAttributesRequest as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for FSItemSetAttributesRequest
impl Debug for FSItemSetAttributesRequest
Sourceimpl Deref for FSItemSetAttributesRequest
impl Deref for FSItemSetAttributesRequest
Sourceimpl Hash for FSItemSetAttributesRequest
impl Hash for FSItemSetAttributesRequest
Sourceimpl Message for FSItemSetAttributesRequest
impl Message for FSItemSetAttributesRequest
Sourceimpl NSObjectProtocol for FSItemSetAttributesRequest
impl NSObjectProtocol for FSItemSetAttributesRequest
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref