#[repr(transparent)]pub struct FSMatchResult(pub NSInteger);FSResource only.Expand description
A type that represents the recognition and usability of a probed resource.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl FSMatchResult
impl FSMatchResult
Sourcepub const NotRecognized: Self
pub const NotRecognized: Self
The probe doesn’t recognize the resource.
This match result is appropriate when the file system module determines that the resource uses a completely different format.
Sourcepub const Recognized: Self
pub const Recognized: Self
The probe recognizes the resource but can’t use it.
This match result is appropriate when the file system module identifies the resource’s format but can’t use it. For example, if the resource uses a newer version than the module supports, the module can name the resource but can’t safely do anything with it.
Sourcepub const UsableButLimited: Self
pub const UsableButLimited: Self
The probe recognizes the resource and is ready to use it, but only in a limited capacity.
This match result is appropriate when the file system module identifies the resource’s format but also identifies incompatibilities. For example, if the module determines the resource uses new features that the module doesn’t support, the module may only offer read-only access.