pub struct FSProbeResult { /* private fields */ }FSResource only.Expand description
An object that represents the results of a specific probe.
For any result value other than FSMatchResult/notRecognized, ensure the name and containerID values are non-nil.
When a container or volume format doesn’t use a name, return an empty string.
Also use an empty string in the case in which the format supports a name, but the value isn’t set yet.
Some container or volume formats may lack a durable UUID on which to base a container identifier. This situation is only valid for unary file systems. In such a case, return a random UUID.
With a block device resource, a probe operation may successfully get a result but encounter an error reading the name or UUID. If this happens, use whatever information is available, and provide an empty string or random UUID for the name or container ID, respectively.
See also Apple’s documentation
Implementations
Sourceimpl FSProbeResult
impl FSProbeResult
Sourcepub unsafe fn result(&self) -> FSMatchResult
pub unsafe fn result(&self) -> FSMatchResult
The match result, representing the recognition and usability of a probed resource.
Sourcepub unsafe fn name(&self) -> Option<Retained<NSString>>
pub unsafe fn name(&self) -> Option<Retained<NSString>>
The resource name, as found during the probe operation.
This value is non-nil unless the FSProbeResult/result is ``FSMatchResult/notRecognized`.
For formats that lack a name, this value may be an empty string.
This value can also be an empty string if the format supports a name, but the value isn’t set yet.
Sourcepub unsafe fn containerID(&self) -> Option<Retained<FSContainerIdentifier>>
Available on crate features FSContainer and FSEntityIdentifier only.
pub unsafe fn containerID(&self) -> Option<Retained<FSContainerIdentifier>>
FSContainer and FSEntityIdentifier only.The container identifier, as found during the probe operation.
This value is non-nil unless the FSProbeResult/result is FSMatchResult/notRecognized`. For formats that lack a durable UUID on which to base a container identifier --- which is only legal for a FSUnaryFileSystem`` — this value may be a random UUID.
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourcepub unsafe fn notRecognizedProbeResult() -> Retained<FSProbeResult>
pub unsafe fn notRecognizedProbeResult() -> Retained<FSProbeResult>
A probe result for an unrecognized file system.
An unrecognized probe result contains nil for its FSProbeResult/name and FSProbeResult/containerID properties.
Sourcepub unsafe fn recognizedProbeResultWithName_containerID(
name: &NSString,
container_id: &FSContainerIdentifier,
) -> Retained<Self>
Available on crate features FSContainer and FSEntityIdentifier only.
pub unsafe fn recognizedProbeResultWithName_containerID( name: &NSString, container_id: &FSContainerIdentifier, ) -> Retained<Self>
FSContainer and FSEntityIdentifier only.Creates a probe result for a recognized file system.
- Parameters:
- name: The resource name, as found during the probe operation. If the file system doesn’t support names, or is awaiting naming, use an empty string.
- containerID: The container identifier, as found during the probe operation. If the file system doesn’t support durable identifiers, use a random UUID.
Sourcepub unsafe fn usableButLimitedProbeResult() -> Retained<FSProbeResult>
pub unsafe fn usableButLimitedProbeResult() -> Retained<FSProbeResult>
A probe result for a recognized file system that is usable, but with limited capabilities.
This kind of probe result lacks the FSProbeResult/name, FSProbeResult/containerID, or both.
Don’t return this result from probing a resource that isn’t limited.
Sourcepub unsafe fn usableButLimitedProbeResultWithName_containerID(
name: &NSString,
container_id: &FSContainerIdentifier,
) -> Retained<Self>
Available on crate features FSContainer and FSEntityIdentifier only.
pub unsafe fn usableButLimitedProbeResultWithName_containerID( name: &NSString, container_id: &FSContainerIdentifier, ) -> Retained<Self>
FSContainer and FSEntityIdentifier only.Creates a probe result for a recognized file system that is usable, but with limited capabilities.
- Parameters:
- name: The resource name, as found during the probe operation. If the file system doesn’t support names, or is awaiting naming, use an empty string.
- containerID: The container identifier, as found during the probe operation. If the file system doesn’t support durable identifiers, use a random UUID.
Sourcepub unsafe fn usableProbeResultWithName_containerID(
name: &NSString,
container_id: &FSContainerIdentifier,
) -> Retained<Self>
Available on crate features FSContainer and FSEntityIdentifier only.
pub unsafe fn usableProbeResultWithName_containerID( name: &NSString, container_id: &FSContainerIdentifier, ) -> Retained<Self>
FSContainer and FSEntityIdentifier only.Creates a probe result for a recognized and usable file system.
- Parameters:
- name: The resource name, as found during the probe operation. If the file system doesn’t support names, or is awaiting naming, use an empty string.
- containerID: The container identifier, as found during the probe operation. If the file system doesn’t support durable identifiers, use a random UUID.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for FSProbeResult
impl AsRef<AnyObject> for FSProbeResult
Sourceimpl AsRef<FSProbeResult> for FSProbeResult
impl AsRef<FSProbeResult> for FSProbeResult
Sourceimpl AsRef<NSObject> for FSProbeResult
impl AsRef<NSObject> for FSProbeResult
Sourceimpl Borrow<AnyObject> for FSProbeResult
impl Borrow<AnyObject> for FSProbeResult
Sourceimpl Borrow<NSObject> for FSProbeResult
impl Borrow<NSObject> for FSProbeResult
Sourceimpl ClassType for FSProbeResult
impl ClassType for FSProbeResult
Sourceconst NAME: &'static str = "FSProbeResult"
const NAME: &'static str = "FSProbeResult"
Sourcetype ThreadKind = <<FSProbeResult as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<FSProbeResult as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for FSProbeResult
impl Debug for FSProbeResult
Sourceimpl Deref for FSProbeResult
impl Deref for FSProbeResult
Sourceimpl Hash for FSProbeResult
impl Hash for FSProbeResult
Sourceimpl Message for FSProbeResult
impl Message for FSProbeResult
Sourceimpl NSObjectProtocol for FSProbeResult
impl NSObjectProtocol for FSProbeResult
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref