#[repr(transparent)]pub struct FSSetXattrPolicy(pub NSUInteger);Available on crate feature
FSVolume only.Expand description
Flags to specify the policy when setting extended file attributes.
See also Apple’s documentation
Tuple Fields
0: NSUIntegerImplementations
Sourceimpl FSSetXattrPolicy
impl FSSetXattrPolicy
Sourcepub const MustCreate: Self
pub const MustCreate: Self
Set the value, but fail if the extended attribute already exists.
Sourcepub const MustReplace: Self
pub const MustReplace: Self
Set the value, but fail if the extended attribute doesn’t already exist.