FSStatFSResult

Struct FSStatFSResult 

pub struct FSStatFSResult { /* private fields */ }
Available on crate feature FSVolume only.
A type used to report a volume’s statistics.

The names of this type’s properties match those in the statfs structure in statfs(2), which reports these values for an FSKit file system. All numeric properties default to 0. Override these values, unless a given property has no meaningful value to provide.

Note: Available space, free space, total space, and used space have properties to express their values either as a number of blocks or a number of bytes. Your module may supply both of these values by setting both the relevant block or byte property. Alternatively, a module may set only one of the two properties. When you do this, FSKit calculates the matching value based on blockSize.

For the read-only fileSystemTypeName, set this value with the designated initializer.

See also Apple’s documentation

Implementations

Source

impl FSStatFSResult

pub unsafe fn blockSize(&self) -> NSInteger

A property for the volume’s block size, in bytes.

This value defaults to 4096. Zero isn’t a valid block size.

pub unsafe fn setBlockSize(&self, block_size: NSInteger)

Setter for blockSize.

pub unsafe fn ioSize(&self) -> NSInteger

A property for the optimal block size with which to perform I/O.

For best performance, specify an ioSize that’s an even multiple of blockSize.

pub unsafe fn setIoSize(&self, io_size: NSInteger)

Setter for ioSize.

pub unsafe fn totalBlocks(&self) -> u64

A property for the volume’s total data block count.

pub unsafe fn setTotalBlocks(&self, total_blocks: u64)

Setter for totalBlocks.

pub unsafe fn availableBlocks(&self) -> u64

A property for the number of free blocks available to a non-superuser on the volume.

pub unsafe fn setAvailableBlocks(&self, available_blocks: u64)

Setter for availableBlocks.

pub unsafe fn freeBlocks(&self) -> u64

A property for the number of free blocks in the volume.

pub unsafe fn setFreeBlocks(&self, free_blocks: u64)

Setter for freeBlocks.

pub unsafe fn usedBlocks(&self) -> u64

A property for the number of used blocks in the volume.

pub unsafe fn setUsedBlocks(&self, used_blocks: u64)

Setter for usedBlocks.

pub unsafe fn totalBytes(&self) -> u64

A property for the total size, in bytes, of the volume.

pub unsafe fn setTotalBytes(&self, total_bytes: u64)

Setter for totalBytes.

pub unsafe fn availableBytes(&self) -> u64

A property for the amount of space available to users, in bytes, in the volume.

pub unsafe fn setAvailableBytes(&self, available_bytes: u64)

Setter for availableBytes.

pub unsafe fn freeBytes(&self) -> u64

A property for the amount of free space, in bytes, in the volume.

pub unsafe fn setFreeBytes(&self, free_bytes: u64)

Setter for freeBytes.

pub unsafe fn usedBytes(&self) -> u64

A property for the amount of used space, in bytes, in the volume.

pub unsafe fn setUsedBytes(&self, used_bytes: u64)

Setter for usedBytes.

pub unsafe fn totalFiles(&self) -> u64

A property for the total number of file slots in the volume,

pub unsafe fn setTotalFiles(&self, total_files: u64)

Setter for totalFiles.

pub unsafe fn freeFiles(&self) -> u64

A property for the total number of free file slots in the volume.

pub unsafe fn setFreeFiles(&self, free_files: u64)

Setter for freeFiles.

pub unsafe fn fileSystemSubType(&self) -> NSInteger

A property for the file system’s subtype or flavor.

Match this value to the FSPersonalities’s FSSubType attribute, if it exists within the EXAppExtensionAttributes dictionary of the module’s Info.plist.

pub unsafe fn setFileSystemSubType(&self, file_system_sub_type: NSInteger)

Setter for fileSystemSubType.

pub unsafe fn fileSystemTypeName(&self) -> Retained<NSString>

A property for the file system type name.

Match this value to the FSShortName attribute within the EXAppExtensionAttributes dictionary of the module’s Info.plist. The maximum allowed length is MFSTYPENAMELEN, including the terminating NUL character.

pub unsafe fn initWithFileSystemTypeName( this: Allocated<Self>, file_system_type_name: &NSString, ) -> Retained<Self>

Creates an statistics result instance, using the given file system type name.

  • Parameters fileSystemTypeName: A type name for the file system. The maximum allowed length is MFSTYPENAMELEN, including the terminating NUL character.
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

Source

impl FSStatFSResult

Methods declared on superclass NSObject.

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}