pub struct FSTask { /* private fields */ }FSTask only.Expand description
A class that enables a file system module to pass log messages and completion notifications to clients.
FSKit creates an instance of this class for each long-running operations.
See also Apple’s documentation
Implementations
Sourceimpl FSTask
impl FSTask
Sourcepub unsafe fn logMessage(&self, str: &NSString)
pub unsafe fn logMessage(&self, str: &NSString)
Logs the given string to the initiating client.
- Parameter str: The string to log.
Sourcepub unsafe fn didCompleteWithError(&self, error: Option<&NSError>)
pub unsafe fn didCompleteWithError(&self, error: Option<&NSError>)
Informs the client that the task completed.
- Parameter error:
nilif the task completed successfully; otherwise, an error that caused the task to fail.
Sourcepub unsafe fn cancellationHandler(
&self,
) -> *mut DynBlock<dyn Fn() -> *mut NSError>
Available on crate feature block2 only.
pub unsafe fn cancellationHandler( &self, ) -> *mut DynBlock<dyn Fn() -> *mut NSError>
block2 only.{
NSProgress *progress = [[NSProgress alloc] init];
yourFileSystemChecker *checker= [[yourFileSystemChecker alloc] init];
checker.work_group = dispatch_group_create();
dispatch_group_enter(checker.work_group);
[task setCancellationHandler:^NSError * _Nullable{
checker.terminate = TRUE;
dispatch_group_wait(checker.work_group);
return nil;
}];
dispatch_async(someQueue, ^{[self performCheck:task progress:progress];});
return progress;
}Note: this example did not account for errors while delivered code must. finally, the
performCheckcode should perform the check operation. It should periodically update the progress object and check itsinterruptedvariable. The check can either complete successfully, complete with an error, or be interrupted. It should then call[task didCompleteWithError:...]wtih the appropriate error value or nil. Finally it shoulddispatch_group_leave(self.work_group);
- Returns: An error if the cancellation did not complete successfully. Any returned error will be logged, and FSKit will then terminate all activity in the container.
Safety
The returned block must be sendable.
Sourcepub unsafe fn setCancellationHandler(
&self,
cancellation_handler: Option<&DynBlock<dyn Fn() -> *mut NSError>>,
)
Available on crate feature block2 only.
pub unsafe fn setCancellationHandler( &self, cancellation_handler: Option<&DynBlock<dyn Fn() -> *mut NSError>>, )
block2 only.Setter for cancellationHandler.
This is copied when set.
Safety
cancellation_handler block must be sendable.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl ClassType for FSTask
impl ClassType for FSTask
Sourceconst NAME: &'static str = "FSTask"
const NAME: &'static str = "FSTask"
Sourcetype ThreadKind = <<FSTask as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<FSTask as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl NSObjectProtocol for FSTask
impl NSObjectProtocol for FSTask
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref