#[repr(transparent)]pub struct FSVolumeCaseFormat(pub NSInteger);Available on crate feature
FSVolume only.Expand description
An enumeration of case-sensitivity support types.
A case-sensitive volume is a volume that treats upper and lower case characters in file and directory names as being distinct from each other. For example, FILE.TXT and file.TXT are different names in a case-sensitive volume, and the same name in a case-insensitive volume.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl FSVolumeCaseFormat
impl FSVolumeCaseFormat
Sourcepub const Insensitive: Self
pub const Insensitive: Self
The volume isn’t case sensitive.
Sourcepub const InsensitiveCasePreserving: Self
pub const InsensitiveCasePreserving: Self
The volume isn’t case sensitive, but supports preserving the case of file and directory names.