FSDirectoryVerifier

Type Alias FSDirectoryVerifier 

pub type FSDirectoryVerifier = u64;
Available on crate feature FSVolume only.
A tool to detect whether the directory contents changed since the last call to enumerate a directory.

Your implementation of FSVolume/Operations/enumerateDirectory(_:startingAt:verifier:attributes:packer:replyHandler:) defines the semantics of this value; it’s opaque to FSKit.

See also Apple’s documentation