pub struct FSEntityIdentifier { /* private fields */ }FSEntityIdentifier only.Expand description
A base type that identifies containers and volumes.
An FSEntityIdentifier is a UUID to identify a container or volume, optionally with eight bytes of qualifying (differentiating) data.
You use the qualifiers in cases in which a file server can receive multiple connections from the same client, which differ by user credentials.
In this case, the identifier for each client is the server’s base UUID, and a unique qualifier that differs by client.
Important: Don’t subclass this class.
See also Apple’s documentation
Implementations
Sourceimpl FSEntityIdentifier
impl FSEntityIdentifier
Sourcepub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Creates an entity identifier with a random UUID.
Sourcepub unsafe fn initWithUUID(
this: Allocated<Self>,
uuid: &NSUUID,
) -> Retained<Self>
pub unsafe fn initWithUUID( this: Allocated<Self>, uuid: &NSUUID, ) -> Retained<Self>
Creates an entity identifier with the given UUID.
- Parameter uuid: The UUID to use for this identifier.
Sourcepub unsafe fn initWithUUID_qualifier(
this: Allocated<Self>,
uuid: &NSUUID,
qualifier: u64,
) -> Retained<Self>
pub unsafe fn initWithUUID_qualifier( this: Allocated<Self>, uuid: &NSUUID, qualifier: u64, ) -> Retained<Self>
Creates an entity identifier with the given UUID and qualifier data as a 64-bit unsigned integer.
- Parameters:
- uuid: The UUID to use for this identifier.
- qualifier: The data to distinguish entities that otherwise share the same UUID.
Sourcepub unsafe fn initWithUUID_data(
this: Allocated<Self>,
uuid: &NSUUID,
qualifier_data: &NSData,
) -> Retained<Self>
pub unsafe fn initWithUUID_data( this: Allocated<Self>, uuid: &NSUUID, qualifier_data: &NSData, ) -> Retained<Self>
Creates an entity identifier with the given UUID and qualifier data.
- Parameters:
- uuid: The UUID to use for this identifier.
- qualifierData: The data to distinguish entities that otherwise share the same UUID.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for FSEntityIdentifier
impl AsRef<AnyObject> for FSEntityIdentifier
Sourceimpl AsRef<FSEntityIdentifier> for FSContainerIdentifier
Available on crate feature FSContainer only.
impl AsRef<FSEntityIdentifier> for FSContainerIdentifier
FSContainer only.Sourcefn as_ref(&self) -> &FSEntityIdentifier
fn as_ref(&self) -> &FSEntityIdentifier
Sourceimpl AsRef<FSEntityIdentifier> for FSEntityIdentifier
impl AsRef<FSEntityIdentifier> for FSEntityIdentifier
Sourceimpl AsRef<FSEntityIdentifier> for FSVolumeIdentifier
Available on crate feature FSVolume only.
impl AsRef<FSEntityIdentifier> for FSVolumeIdentifier
FSVolume only.Sourcefn as_ref(&self) -> &FSEntityIdentifier
fn as_ref(&self) -> &FSEntityIdentifier
Sourceimpl AsRef<NSObject> for FSEntityIdentifier
impl AsRef<NSObject> for FSEntityIdentifier
Sourceimpl Borrow<AnyObject> for FSEntityIdentifier
impl Borrow<AnyObject> for FSEntityIdentifier
Sourceimpl Borrow<FSEntityIdentifier> for FSContainerIdentifier
Available on crate feature FSContainer only.
impl Borrow<FSEntityIdentifier> for FSContainerIdentifier
FSContainer only.Sourcefn borrow(&self) -> &FSEntityIdentifier
fn borrow(&self) -> &FSEntityIdentifier
Sourceimpl Borrow<FSEntityIdentifier> for FSVolumeIdentifier
Available on crate feature FSVolume only.
impl Borrow<FSEntityIdentifier> for FSVolumeIdentifier
FSVolume only.Sourcefn borrow(&self) -> &FSEntityIdentifier
fn borrow(&self) -> &FSEntityIdentifier
Sourceimpl Borrow<NSObject> for FSEntityIdentifier
impl Borrow<NSObject> for FSEntityIdentifier
Sourceimpl ClassType for FSEntityIdentifier
impl ClassType for FSEntityIdentifier
Sourceconst NAME: &'static str = "FSEntityIdentifier"
const NAME: &'static str = "FSEntityIdentifier"
Sourcetype ThreadKind = <<FSEntityIdentifier as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<FSEntityIdentifier as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl CopyingHelper for FSEntityIdentifier
impl CopyingHelper for FSEntityIdentifier
Sourcetype Result = FSEntityIdentifier
type Result = FSEntityIdentifier
Self if the type has no
immutable counterpart. Read moreSourceimpl Debug for FSEntityIdentifier
impl Debug for FSEntityIdentifier
Sourceimpl Deref for FSEntityIdentifier
impl Deref for FSEntityIdentifier
Sourceimpl Hash for FSEntityIdentifier
impl Hash for FSEntityIdentifier
Sourceimpl Message for FSEntityIdentifier
impl Message for FSEntityIdentifier
Sourceimpl NSCopying for FSEntityIdentifier
impl NSCopying for FSEntityIdentifier
Sourceimpl NSObjectProtocol for FSEntityIdentifier
impl NSObjectProtocol for FSEntityIdentifier
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref