#[repr(transparent)]pub struct FSErrorCode(pub NSInteger);FSKitError only.Expand description
A code that indicates a specific FSKit error.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl FSErrorCode
impl FSErrorCode
Sourcepub const ModuleLoadFailed: Self
pub const ModuleLoadFailed: Self
The module failed to load.
Sourcepub const ResourceUnrecognized: Self
pub const ResourceUnrecognized: Self
FSKit didn’t recognize the resource, and probing failed to find a match.
Sourcepub const ResourceDamaged: Self
pub const ResourceDamaged: Self
The resource is damaged.
This error indicates the resource needs a repair operation, or that a repair operation failed.
Note: The status in this error applies to the resource. A failing repair operation reports a more specific error status.
Sourcepub const ResourceUnusable: Self
pub const ResourceUnusable: Self
FSKit recognizes the resource, but the resource isn’t usable.
For example, this error occurs when a resource uses a file system’s internal feature flags. If the only modules that support the file system don’t support those feature flags, this code indicates an unusable resource. The error tells the person using the module why the resource isn’t usable.
Sourcepub const StatusOperationInProgress: Self
pub const StatusOperationInProgress: Self
An operation is in progress.
Sourcepub const StatusOperationPaused: Self
pub const StatusOperationPaused: Self
An operation is paused.
Sourcepub const InvalidDirectoryCookie: Self
pub const InvalidDirectoryCookie: Self
While enumerating a directory, the given cookie didn’t resolve to a valid directory entry.