FSFileName

Struct FSFileName 

pub struct FSFileName { /* private fields */ }
Available on crate feature FSFileName only.
The name of a file, expressed as a data buffer.

FSFileName is the class that carries filenames from the kernel to FSModule instances, and carries names back to the kernel as part of directory enumeration.

A filename is usually a valid UTF-8 sequence, but can be an arbitrary byte sequence that doesn’t conform to that format. As a result, the data property always contains a value, but the string property may be empty. An FSModule can receive an FSFileName that isn’t valid UTF-8 in two cases:

  1. A program passes erroneous data to a system call. The FSModule treats this situation as an error.
  2. An FSModule lacks the character encoding used for a file name. This situation occurs because some file system formats consider a filename to be an arbitrary “bag of bytes,” and leave character encoding up to the operating system. Without encoding information, the FSModule can only pass back the names it finds on disk. In this case, the behavior of upper layers such as <doc ://com.apple.documentation/documentation/Foundation/NSFileManager> is unspecified. However, the FSModule must support looking up such names and using them as the source name of rename operations. The FSModule must also be able to support filenames that are derivatives of filenames returned from directory enumeration. Derivative filenames include Apple Double filenames ("._Name"), and editor backup filenames.

Important: Don’t subclass this class.

See also Apple’s documentation

Implementations

Source

impl FSFileName

pub unsafe fn data(&self) -> Retained<NSData>

The byte sequence of the filename, as a data object.

This property always provides a value.

pub unsafe fn string(&self) -> Option<Retained<NSString>>

The filename, represented as a Unicode string.

If the value of the filename’s FSFileName/data is not a valid UTF-8 byte sequence, this property is empty.

pub unsafe fn debugDescription(&self) -> Retained<NSString>

The filename, represented as a potentially lossy conversion to a string.

The exact details of the string conversion may change in the future.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn initWithCString( this: Allocated<Self>, name: NonNull<c_char>, ) -> Retained<Self>

Initializes a filename from a null-terminated character sequence.

Note: This initializer is unavailable in Swift. Use initWithData: or initWithString: instead.

  • Parameter name: A pointer to a C string.
Safety

name must be a valid pointer.

pub unsafe fn initWithBytes_length( this: Allocated<Self>, bytes: NonNull<c_char>, length: NSUInteger, ) -> Retained<Self>

Initializes a file name by copying a character sequence from a byte array.

Note: This initializer is unavailable in Swift. Use initWithData: or initWithString: instead.

  • Parameters:
  • bytes: A pointer to the character data to copy, up to a maximum of length. The sequence terminates if a NUL character exists prior to length.
  • length: The size of the bytes array.
Safety

bytes must be a valid pointer.

pub unsafe fn initWithData( this: Allocated<Self>, name: &NSData, ) -> Retained<Self>

Creates a filename by copying a character sequence data object.

This initializer copies up to name.length characters of the sequence pointed to by bytes.

  • Parameter name: The data object containing the character sequence to use for the filename. The sequence terminates if a NUL character exists prior to name.length.
pub unsafe fn initWithString( this: Allocated<Self>, name: &NSString, ) -> Retained<Self>

Creates a filename by copying a character sequence from a string instance.

This initializer copies the UTF-8 representation of the characters in string. If string contains a NUL character, the sequence terminates.

  • Parameter name: The string containing the character sequence to use for the filename.
pub unsafe fn nameWithCString(name: NonNull<c_char>) -> Retained<Self>

Creates a filename from a null-terminated character sequence.

  • Parameter name: A pointer to a C string.
Safety

name must be a valid pointer.

pub unsafe fn nameWithBytes_length( bytes: NonNull<c_char>, length: NSUInteger, ) -> Retained<Self>

Creates a filename by copying a character sequence from a byte array.

  • Parameters:
  • bytes: A pointer to the character data to copy, up to a maximum of length. The sequence terminates if a NUL character exists prior to length.
  • length: The size of the bytes array.
Safety

bytes must be a valid pointer.

pub unsafe fn nameWithData(name: &NSData) -> Retained<Self>

Creates a filename by copying a character sequence data object.

This initializer copies up to name.length characters of the sequence pointed to by bytes.

  • Parameter name: The data object containing the character sequence to use for the filename. The sequence terminates if a NUL character exists prior to name.length.
pub unsafe fn nameWithString(name: &NSString) -> Retained<Self>

Creates a filename by copying a character sequence from a string instance.

This initializer copies the UTF-8 representation of the characters in string. If string contains a NUL character, the sequence terminates.

  • Parameter name: The string containing the character sequence to use for the filename.
Source

impl FSFileName

Methods declared on superclass NSObject.

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}